/** Setup MCU for I-radio
 *  V0 2013-01-15
 */

//Devide by last 4 Bit + 1; MSB is start signal
//must reach target frequency of .5 to 1MHz from Osc / 2 
#define PLLSetting  0b10000011

//Disable or Enable RTC with int on external high frequ crystal and clear int flag
#define RTCen	0b01100011
#define RTCdis    0b01100000

void InitMCU()
{
	//Init MCU core
	AUXR1=0b10000000;		//lower power consumption below 8 MHz
	DIVM=0x00;		//run CPU at full speed
	PCONA=0b01111101;		//Disable EEPROM, analog voltage comperators, ADC, I2C, SPI, CCU
				//enable RTC, UART

	//Init port pins
	//Write 1 to port pin if internal control (SPI, UART, ... ) of the port pin is required 

	//P0.0 Quasi-Bi Encoder0 A
	//P0.1 Quasi-Bi Encoder0 B
	//P0.2 Quasi-Bi Key0 A
	//P0.3 Quasi-Bi key0 B
	//P0.4 Quasi-Bi Encoder1 A
	//P0.5 Quasi-Bi Encoder1 B
	//P0.6 Quasi-Bi Key1 A
	//P0.7 Quasi-Bi key1 B
	P0M1  = 0b00000000;
	P0M2  = 0b00000000;
	//apply save start-up configuration
	P0    = 0b11111111;

	//P1.0 Push-Pull TxD
	//P1.1 Input RxD
	//P1.2 Open-Drain SCL
	//P1.3 Open-Drain SDA
	//P1.4 Quasi-Bi NC
	//P1.5 /Reset
	//P1.6 Quasi-Bi NC
	//P1.7 Quasi-Bi /RC5 input
	P1M1 = 0b00001110;
	P1M2 = 0b00001101;
	//apply save start-up configuration
	P1   = 0b11110000;	//communication off

	//P2.0 Quasi-Bi NC
	//P2.1 Quasi-Bi NC
	//P2.2 Push-PUll Pwr Sw
	//P2.3 Push-Pull Amp Off
	//P2.4 Quasi-Bi NC
	//P2.5 Push-Pull Pi On
	//P2.6 Quasi-Bi NC
	//P2.7 Quasi-Bi NC
	P2M1 = 0b00000000;
    	P2M2 = 0b00101100;
	//apply save start-up configuration
	P2   = 0b11011011;	//everything off

    	//P3 is used for the resonator

	//Setup UART
    	// Seriellen Port einstellen
    	// Mode 1, Baud Rate Generator
    	// rate = CCLK/((BRGR1, BRGR0)+16)
    	//      = 115200 Baud
    	BRGR1 = 0;
         BRGR0 = 36;
         SCON = 0b01010000;	//Mode 1, do receive data 
    	// after enable of baud rate generator BRGRX can not be writen to anymore!
    	BRGCON = 0b00000011;
    
	//Init RTC of P89LPC93X
	// config RTC as Timer with 6*10^6/128/25=1875 reload => 25Hz int source
    	RTCH = 0x07; 
    	RTCL = 0x53;
    	RTCCON = RTCdis;
	//enable when configured

    	//switch WTD off or we will be burried under ints
    	WDCON &= 0b11111011; 	//set WD_RUN=0

	//Setup Timer 0 and Timer 1

    	// config Timer 0 for RC5 receiver
    	// config Timer 1 for encoder decoding
    	TMOD = 0b00000010;	//Init T0 (auto reload timer), T1 (8 bit counter with 1:32 prescaler form 366Hz at 6MHz clk)
    	TCON = 0b01010000;	//gibt T0 & T1 frei
    	TH0 = 256-166;		//T0 high Byte => Reload-Wert
        		        		//clk source is PCLK=CCLK/2, extended by Software with a 1:4 postscaler
	//Init Int
    	IEN0 = 0b11001010;	//Interupt internal RTC (Bit 6) enable
    				//T0 und T1 enable
    	RTCCON = RTCen;
}